"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSuggestTooltipKey = getSuggestTooltipKey;
exports.queryTriggerText = queryTriggerText;
exports.selectEmoji = selectEmoji;
exports.commands = exports.plugins = exports.spec = void 0;

var _core = require("@bangle.dev/core");

var _tooltip = require("@bangle.dev/tooltip");

var _prosemirrorState = require("prosemirror-state");

var _utils = require("./utils");

var _pmUtils = require("@bangle.dev/pm-utils");

var _jsUtils = require("@bangle.dev/js-utils");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var {
  decrementSuggestTooltipCounter,
  incrementSuggestTooltipCounter,
  updateSuggestTooltipCounter,
  removeSuggestMark,
  resetSuggestTooltipCounter,
  defaultKeys
} = _tooltip.suggestTooltip;
var spec = specFactory;
exports.spec = spec;
var plugins = pluginsFactory;
exports.plugins = plugins;
var commands = {
  queryTriggerText,
  selectEmoji
};
exports.commands = commands;
var defaultTrigger = ':';
var defaultMaxItems = 2000;

function specFactory() {
  var {
    markName,
    trigger = defaultTrigger
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var spec = _tooltip.suggestTooltip.spec({
    markName,
    trigger
  });

  return _objectSpread(_objectSpread({}, spec), {}, {
    options: _objectSpread(_objectSpread({}, spec.options), {}, {
      trigger
    })
  });
}

var keyStore = (0, _core.pluginKeyStore)();

function pluginsFactory() {
  var {
    key = new _prosemirrorState.PluginKey('emojiSuggestMenu'),
    markName,
    tooltipRenderOpts = {},
    getEmojiGroups,
    maxItems = defaultMaxItems,
    squareSide = 32,
    squareMargin = 2,
    rowWidth = 400,
    palettePadding = 16
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return _ref => {
    var {
      schema,
      specRegistry
    } = _ref;
    var {
      trigger
    } = specRegistry.options[markName];
    var suggestTooltipKey = keyStore.create(key, 'suggestTooltipKey'); // We are converting to DOM elements so that their instances
    // can be shared across plugins.

    var tooltipDOMSpec = (0, _tooltip.createTooltipDOM)(tooltipRenderOpts.tooltipDOMSpec);

    var getIsTop = () => tooltipDOMSpec.dom.getAttribute('data-popper-placement') === 'top-start';

    if (!schema.marks[markName]) {
      (0, _jsUtils.bangleWarn)("Couldn't find the markName:".concat(markName, ", please make sure you have initialized to use the same markName you initialized the spec with"));
      throw new Error("markName ".concat(markName, " not found"));
    }

    var selectedEmojiSquareId = (0, _jsUtils.uuid)(6);

    var updateCounter = keyType => {
      return (state, dispatch, view) => {
        requestAnimationFrame(() => {
          var selectedEmoji = document.getElementById(selectedEmojiSquareId);

          if (selectedEmoji) {
            if ('scrollIntoViewIfNeeded' in document.body) {
              selectedEmoji.scrollIntoViewIfNeeded(false);
            } else if (selectedEmoji.scrollIntoView) {
              selectedEmoji.scrollIntoView(false);
            }
          }

          view.focus();
        });

        if (keyType === 'LEFT') {
          return decrementSuggestTooltipCounter(suggestTooltipKey)(state, dispatch, view);
        }

        if (keyType === 'RIGHT') {
          return incrementSuggestTooltipCounter(suggestTooltipKey)(state, dispatch, view);
        }

        var goUp = keyType === 'UP' ? !getIsTop() : getIsTop();
        var namedEmojiGroups = getEmojiGroups(queryTriggerText(key)(state));
        var {
          counter
        } = suggestTooltipKey.getState(state);
        var {
          rowCount
        } = (0, _utils.getSquareDimensions)({
          rowWidth,
          squareMargin,
          squareSide
        });
        var newCounter = (0, _utils.resolveRowJump)(counter, goUp ? -1 : 1, rowCount, namedEmojiGroups);

        if (newCounter == null) {
          return false;
        }

        return updateSuggestTooltipCounter(suggestTooltipKey, newCounter)(state, dispatch, view);
      };
    };

    return [(0, _pmUtils.valuePlugin)(key, {
      getEmojiGroups,
      maxItems,
      tooltipContentDOM: tooltipDOMSpec.contentDOM,
      markName,
      squareSide,
      squareMargin,
      palettePadding,
      selectedEmojiSquareId,
      rowWidth
    }), _tooltip.suggestTooltip.plugins({
      key: suggestTooltipKey,
      markName,
      trigger,
      tooltipRenderOpts: _objectSpread(_objectSpread({}, tooltipRenderOpts), {}, {
        tooltipDOMSpec
      }),
      keybindings: _objectSpread(_objectSpread({}, defaultKeys), {}, {
        left: 'ArrowLeft',
        right: 'ArrowRight'
      }),
      onEnter: (state, dispatch, view) => {
        var emojiGroups = getEmojiGroups(queryTriggerText(key)(state));
        var matchedEmojis = emojiGroups.flatMap(r => r[1]);

        if (matchedEmojis.length === 0) {
          return removeSuggestMark(key)(state, dispatch, view);
        }

        var {
          counter
        } = suggestTooltipKey.getState(state);
        var {
          item: activeItem
        } = (0, _utils.resolveCounter)(counter, emojiGroups);

        if (!activeItem) {
          return removeSuggestMark(key)(state, dispatch, view);
        }

        var emojiAlias = activeItem[0];
        (0, _pmUtils.rafCommandExec)(view, resetSuggestTooltipCounter(suggestTooltipKey));
        return selectEmoji(key, emojiAlias)(state, dispatch, view);
      },
      onArrowDown: updateCounter('DOWN'),
      onArrowUp: updateCounter('UP'),
      onArrowLeft: updateCounter('LEFT'),
      onArrowRight: updateCounter('RIGHT')
    })];
  };
}

function getSuggestTooltipKey(key) {
  return keyStore.get(key, 'suggestTooltipKey');
}
/** Commands */


function queryTriggerText(key) {
  return _tooltip.suggestTooltip.queryTriggerText(getSuggestTooltipKey(key));
}

function selectEmoji(key, emojiAlias) {
  return (state, dispatch, view) => {
    var emojiNode = state.schema.nodes.emoji.create({
      emojiAlias: emojiAlias
    });
    return _tooltip.suggestTooltip.replaceSuggestMarkWith(key, emojiNode)(state, dispatch, view);
  };
}